@@ -45,6 +45,11 @@ class Profile:
             constants.CONFIG_EXCHANGE_TYPE: constants.DEFAULT_EXCHANGE_TYPE,
         }
     }
+    PARTIALLY_MANAGED_ELEMENTS_FORCED_DEFAULT_KEYS = {
+        constants.CONFIG_EXCHANGES: {
+            constants.CONFIG_ENABLED_OPTION: False,
+        }
+    }
     PARTIALLY_MANAGED_ELEMENTS_ALLOWED_KEYS = {
         constants.CONFIG_EXCHANGES: [
             constants.CONFIG_ENABLED_OPTION,
@@ -89,13 +94,33 @@ class Profile:
 
     def save_config(self, global_config: dict):
         """
-        Save ths profile config
+        Save this profile config
         :param global_config: the bot config containing profile data
         :return: None
         """
         for element in self.FULLY_MANAGED_ELEMENTS:
             if element in global_config:
                 self.config[element] = global_config[element]
+        self.sync_partially_managed_elements(global_config)
+        self.validate_and_save_config()
+
+    def remove_deleted_elements(self, global_config):
+        """
+        Removes elements from self.PARTIALLY_MANAGED_ELEMENTS
+        that are in profile but not in global config
+        """
+        for element in self.PARTIALLY_MANAGED_ELEMENTS:
+            if element in global_config and element in self.config:
+                current_elements = list(self.config[element])
+                to_keep_elements = set(global_config[element])
+                for key in current_elements:
+                    if key not in to_keep_elements:
+                        self.config[element].pop(key)
+
+    def sync_partially_managed_elements(self, global_config):
+        """
+        Update the partially managed elements of this profile using the given configuration
+        """
         for element in self.PARTIALLY_MANAGED_ELEMENTS:
             if element in global_config:
                 allowed_keys = self.PARTIALLY_MANAGED_ELEMENTS_ALLOWED_KEYS.get(
@@ -105,7 +130,6 @@ class Profile:
                     self._filter_fill_elements(
                         global_config, self.config, element, allowed_keys
                     )
-        self.validate_and_save_config()
 
     def validate(self):
         """
@@ -211,26 +235,8 @@ class Profile:
         config: dict, profile_config: dict, element: str, template: dict
     ):
         if element in config:
-            for key, val in profile_config[element].items():
-                if key in config[element]:
-                    if isinstance(config[element][key], dict):
-                        # merge profile values for element[key]
-                        Profile._merge_partially_managed_element(
-                            config[element], profile_config[element], key, template
-                        )
-                    else:
-                        # overwrite element[key] by profile value
-                        config[element][key] = copy.deepcopy(
-                            profile_config[element][key]
-                        )
-                else:
-                    # use profile value for element[key]
-                    if isinstance(val, dict):
-                        config[element][key] = Profile._get_element_from_template(
-                            template, val
-                        )
-                    else:
-                        config[element][key] = val
+            Profile._merge_profile_values(config, profile_config, element, template)
+            Profile._apply_forced_default_values(config, profile_config, element)
         else:
             # use profile value for element
             config[element] = {
@@ -238,6 +244,51 @@ class Profile:
                 for key, val in profile_config[element].items()
             }
 
+    @staticmethod
+    def _merge_profile_values(
+        config: dict, profile_config: dict, element: str, template: dict
+    ):
+        for key, val in profile_config[element].items():
+            if key in config[element]:
+                if isinstance(config[element][key], dict):
+                    # merge profile values for element[key]
+                    Profile._merge_partially_managed_element(
+                        config[element], profile_config[element], key, template
+                    )
+                else:
+                    # overwrite element[key] by profile value
+                    config[element][key] = copy.deepcopy(profile_config[element][key])
+            else:
+                # use profile value for element[key]
+                if isinstance(val, dict):
+                    config[element][key] = Profile._get_element_from_template(
+                        template, val
+                    )
+                else:
+                    config[element][key] = val
+
+    @staticmethod
+    def _apply_forced_default_values(config: dict, profile_config: dict, element: str):
+        if element in Profile.PARTIALLY_MANAGED_ELEMENTS_FORCED_DEFAULT_KEYS:
+            for config_key, config_val in config[element].items():
+                if config_key not in profile_config[element]:
+                    for config_sub_element in config_val:
+                        if (
+                            config_sub_element
+                            in Profile.PARTIALLY_MANAGED_ELEMENTS_FORCED_DEFAULT_KEYS[
+                                element
+                            ]
+                        ):
+                            # item not in profile, it will be added to profile upon save
+                            # use forced default profile value for forced default keys
+                            config[element][config_key][
+                                config_sub_element
+                            ] = Profile.PARTIALLY_MANAGED_ELEMENTS_FORCED_DEFAULT_KEYS[
+                                element
+                            ][
+                                config_sub_element
+                            ]
+
     @staticmethod
     def _get_element_from_template(template: dict, profile_values: dict) -> dict:
         merged_values = copy.deepcopy(template)
